==> mgpcli-0.0.1.tar.gz: lib/src/commands/create.dart <==
import 'dart:async';
import 'dart:io';
import '../base/common.dart';
import '../base/file_system.dart';
import '../base/os.dart';
import '../runner/mpcli_command.dart';
import '../base/os.dart' show os;
import '../../utils/util.dart';


class CreateCommand extends MpcliCommand {
  CreateCommand() {
    argParser.addOption(
      'description',
      defaultsTo: 'A new Flutter project.',
      help: 'The description to use for your new Flutter project. This string ends up in the pubspec.yaml file.',
    );

    argParser.addOption(
      'project-name',
      defaultsTo: null,
      help: 'The project name for this new Flutter project. This must be a valid dart package name.',
    );
    argParser.addOption(
      'ios-language',
      abbr: 'i',
      defaultsTo: 'swift',
      allowed: <String>['objc', 'swift'],
    );
    argParser.addOption(
      'android-language',
      abbr: 'a',
      defaultsTo: 'kotlin',
      allowed: <String>['java', 'kotlin'],
    );

    argParser.addFlag(
      'web',
      negatable: true,
      defaultsTo: false,
      hide: true,
      help: '(Experimental) Generate the web specific tooling. Only supported '
        'on non-stable branches',
    );
  }

  @override
  final String name = 'create';

  @override
  final String description = 'Create a new Flutter project.\n\n'
    'If run on a project that already exists, this will repair the project, recreating any files that are missing.';


  @override
  Future<MpcliCommandResult> runCommand() async {

    final Directory dirFile = currentFolder();
    final String currentPath = currentFolderPath();
    // final Directory wbFlutterModule = fs.directory(fs.file(fs.path.join(currentPath, 'wb_flutter_module')));
    final String fileRoot = userRootPath();
    // final File zipFile = fs.file(fs.path.join(fileRoot, 'wb_flutter_module.zip'));
    final Directory srcDir = fs.directory(fs.path.join(fileRoot, 'template', 'module'));
    final Directory destDir = fs.directory(currentPath);
    print('currentPath = ${currentPath}');
    print('fileRoot = ${fileRoot}');
    // print('wbFlutterModule = ${wbFlutterModule}');
    
    print('Downloading the template, wait a moment please...');

    try {
        // if (wbFlutterModule.existsSync()) {
        //   wbFlutterModule.deleteSync(recursive: true);
        // }

        dirFile.createSync(recursive: true);

        // await cliUnzip(zipFile,'.');
        await copyDirectorySync(srcDir, destDir);

        final Directory macFile = fs.directory(fs.file(fs.path.join(currentPath, '__MACOSX')));
        if (macFile.existsSync()) {
          macFile.deleteSync(recursive: true);
        }

        //magpie-SDK动态指定android目录下的local.properties内容
        await writeLocalProperties(fs.file(fs.path.join(currentPath,"android_magpie","local.properties")));

        print('Download successful, the template project is in $currentPath');

      } catch (e) {
        throwToolExit('Failed to fetch third-party artifact $dirFile: $e');
    }
    return null;
  }
}

==> mgpcli-0.1.45.tar.gz: lib/src/commands/create.dart <==
import 'dart:async';
import 'dart:io';
import '../base/common.dart';
import '../base/file_system.dart';
import '../base/os.dart';
import '../runner/mpcli_command.dart';
import '../base/os.dart' show os;
import '../../utils/util.dart';


class CreateCommand extends MpcliCommand {
  CreateCommand() {
    argParser.addOption(
      'description',
      defaultsTo: 'A new Flutter project.',
      help: 'The description to use for your new Flutter project. This string ends up in the pubspec.yaml file.',
    );

    argParser.addOption(
      'project-name',
      defaultsTo: null,
      help: 'The project name for this new Flutter project. This must be a valid dart package name.',
    );
    argParser.addOption(
      'ios-language',
      abbr: 'i',
      defaultsTo: 'swift',
      allowed: <String>['objc', 'swift'],
    );
    argParser.addOption(
      'android-language',
      abbr: 'a',
      defaultsTo: 'kotlin',
      allowed: <String>['java', 'kotlin'],
    );

    argParser.addFlag(
      'web',
      negatable: true,
      defaultsTo: false,
      hide: true,
      help: '(Experimental) Generate the web specific tooling. Only supported '
        'on non-stable branches',
    );
  }

  @override
  final String name = 'create';

  @override
  final String description = 'Create a new Flutter project.\n\n'
    'If run on a project that already exists, this will repair the project, recreating any files that are missing.';


  @override
  Future<MpcliCommandResult> runCommand() async {

    final Directory dirFile = currentFolder();
    final String currentPath = currentFolderPath();
    final Directory wbFlutterModule = fs.directory(fs.file(fs.path.join(currentPath, 'wb_flutter_module')));
    final String fileRoot = userRootPath();
    final File zipFile = fs.file(fs.path.join(fileRoot, 'wb_flutter_module.zip'));

    print('currentPath = ${currentPath}');
    print('fileRoot = ${fileRoot}');
    print('wbFlutterModule = ${wbFlutterModule}');
    
    print('Downloading the template, wait a moment please...');

    try {
        if (wbFlutterModule.existsSync()) {
          wbFlutterModule.deleteSync(recursive: true);
        }

        dirFile.createSync(recursive: true);

        await cliUnzip(zipFile,'.');

        final Directory macFile = fs.directory(fs.file(fs.path.join(currentPath, '__MACOSX')));
        if (macFile.existsSync()) {
          macFile.deleteSync(recursive: true);
        }

        //magpie-SDK动态指定android目录下的local.properties内容
        await writeLocalProperties(fs.file(fs.path.join(currentPath,"android_magpie","local.properties")));

        print('Download successful, the template project is in $currentPath');

      } catch (e) {
        throwToolExit('Failed to fetch third-party artifact $dirFile: $e');
    }
    return null;
  }

}
